@@ -1,6 +1,12 @@
 
 package Person;
 
+use overload
+	'""' => 'stringify',
+	'==' => 'equals',
+	'!=' => 'notequals',
+	fallback => 1;
+
 sub new
 {
    ++$n;
@@ -65,4 +71,24 @@ sub same
    '';
 }
 
+sub stringify
+{
+   my $self = shift;
+
+   return "$self->{firstname} $self->{name}";
+}
+
+sub equals
+{
+   my $a = shift;
+   my $b = shift;
+
+   return ( $a->{firstname} eq $b->{firstname} &&
+   	         $a->{name} eq $b->{name}         )
+}
+
+sub notequals {
+    !equals(@_);
+}
+
 1;
